%define module_name paramiko

# disable tests, pytest-relaxed which we don't have and even
# if we would have it, it needs pytests < 3.3
%bcond_with tests

Summary:       SSH2 protocol for Python
Name:          python-%{module_name}
Version:       2.6.0
Release:       %mkrel 1
Url:           https://github.com/paramiko/paramiko/
License:       LGPLv2+
Group:         Development/Python
Source0:       https://pypi.io/packages/source/p/%{module_name}/%{module_name}-%{version}.tar.gz
# Missing from pypi source tarball
Source1:       test_dss.key-cert.pub
Source2:       test_ecdsa_256.key-cert.pub
Source3:       test_ed25519.key-cert.pub
Source4:       test_rsa.key-cert.pub
BuildArch:     noarch

%global paramiko_desc \
Paramiko (a combination of the esperanto words for "paranoid" and "friend") is\
a module for python 2.3 or greater that implements the SSH2 protocol for secure\
(encrypted and authenticated) connections to remote machines. Unlike SSL (aka\
TLS), the SSH2 protocol does not require heirarchical certificates signed by a\
powerful central authority. You may know SSH2 as the protocol that replaced\
telnet and rsh for secure access to remote shells, but the protocol also\
includes the ability to open arbitrary channels to remote services across an\
encrypted tunnel. (This is how sftp works, for example.)\


%description
%{paramiko_desc}

Python 2 version.


%package -n python2-%{module_name}
Group:         Development/Python
Summary:       SSH2 protocol library for python 2
BuildRequires: pkgconfig(python2)
BuildRequires: python2dist(cryptography)
BuildRequires: python2dist(setuptools)
%if %{with tests}
BuildRequires: python2dist(pytest)
BuildRequires: python2dist(funcsigs)
BuildRequires: python2dist(enum34)
BuildRequires: python2dist(mock)
BuildRequires: python2dist(pyasn1)
BuildRequires: python2dist(bcrypt)
BuildRequires: python2dist(pynacl)
BuildRequires: python2dist(pytest-relaxed)
%endif
Requires:      python2dist(cryptography)
Requires:      python2dist(enum34)
Provides:      %{module_name} = %{version}-%{release}

Obsoletes:     python-paramiko < 2.4.2-3
Provides:      python-paramiko = %{version}-%{release}

%description -n python2-%{module_name}
%{paramiko_desc}

Python 2 version.


%package -n python3-%{module_name}
Group:         Development/Python
Summary:       SSH2 protocol library for python 3
BuildRequires: pythonegg(3)(setuptools)
BuildRequires: pythonegg(3)(cryptography)
BuildRequires: python3-devel
%if %{with tests}
BuildRequires: python3dist(pytest)
BuildRequires: python3dist(funcsigs)
BuildRequires: python3dist(pyasn1)
BuildRequires: python3dist(bcrypt)
BuildRequires: python3dist(pynacl)
BuildRequires: python3dist(pytest-relaxed)
%endif
Requires:      pythonegg(3)(cryptography)

%description -n python3-%{module_name}
%{paramiko_desc}

Python 3 version.


%prep
%autosetup -n %{module_name}-%{version}

# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info

%{__chmod} a-x demos/*
%{__sed} -i -e '/^#!/,1d' demos/*

for i in %{_sourcedir}/*.pub; do
  install -Dpm644 $i tests/cert_support/$(basename $i)
done

%build
%py2_build
%py3_build

%install
%py2_install
%py3_install

%if %{with tests}
%check
# Remove sftp test
rm -f tests/test_sftp*.py
PYTHONPATH=%{buildroot}%{python2_sitelib} pytest-%{python2_version}
PYTHONPATH=%{buildroot}%{python3_sitelib} pytest-%{python3_version}
%endif

%files -n python2-%{module_name}
%license LICENSE
%doc README.rst
%{python2_sitelib}/%{module_name}-*.egg-info/
%{python2_sitelib}/%{module_name}/


%files -n python3-%{module_name}
%license LICENSE
%doc README.rst
%{python3_sitelib}/%{module_name}-*.egg-info/
%{python3_sitelib}/%{module_name}/




%changelog
* Fri Jul 12 2019 daviddavid <daviddavid> 2.6.0-1.mga7
+ Revision: 1420517
- new version: 2.6.0 (mga#25094)
- rename python-paramiko to python2-paramiko

* Wed Jan 09 2019 shlomif <shlomif> 2.4.2-2.mga7
+ Revision: 1353674
- Rebuild for python3 3.7

* Tue Jan 01 2019 luigiwalser <luigiwalser> 2.4.2-1.mga7
+ Revision: 1347844
- 2.4.2

* Mon Oct 29 2018 wally <wally> 2.4.1-3.mga7
+ Revision: 1326475
- make py2 pkg to require enum34
- drop old obsoletes

* Thu Sep 20 2018 umeabot <umeabot> 2.4.1-2.mga7
+ Revision: 1289586
- Mageia 7 Mass Rebuild

* Sun Apr 22 2018 wally <wally> 2.4.1-1.mga7
+ Revision: 1220975
- new version 2.4.1

* Sun Apr 01 2018 shlomif <shlomif> 2.0.8-1.mga7
+ Revision: 1214039
- New version 2.0.8 ( MGA#22837 )

* Sun Aug 06 2017 philippem <philippem> 2.0.0-2.mga7
+ Revision: 1137703
- convert to pythonegg requires
+ pterjan <pterjan>
- Rebuild for python 3.6

* Fri May 13 2016 philippem <philippem> 2.0.0-1.mga6
+ Revision: 1014422
- update to 2.0.0

* Fri Feb 19 2016 umeabot <umeabot> 1.15.2-3.mga6
+ Revision: 971000
- Mageia 6 Mass Rebuild

* Sat Oct 10 2015 tv <tv> 1.15.2-2.mga6
+ Revision: 888946
- rebuild for python 3.5

* Tue Jan 06 2015 philippem <philippem> 1.15.2-1.mga5
+ Revision: 808729
- update to 1.15.2, add Python 3, support OpenSSH 6.7 mga#14724

* Wed Oct 15 2014 umeabot <umeabot> 1.12.4-4.mga5
+ Revision: 746527
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.12.4-3.mga5
+ Revision: 727918
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.12.4-2.mga5
+ Revision: 688202
- Mageia 5 Mass Rebuild

* Thu Jul 03 2014 philippem <philippem> 1.12.4-1.mga5
+ Revision: 642768
- Update to 1.12.4
+ pterjan <pterjan>
- Rebuild for new Python

* Fri Mar 07 2014 philippem <philippem> 1.12.2-1.mga5
+ Revision: 600907
- Update to 1.12.2

* Sat Feb 08 2014 dams <dams> 1.12.1-1.mga5
+ Revision: 585702
- new version 1.12.1

* Tue Oct 22 2013 umeabot <umeabot> 1.12.0-4.mga4
+ Revision: 543855
- Mageia 4 Mass Rebuild

* Fri Oct 18 2013 dlucio <dlucio> 1.12.0-3.mga4
+ Revision: 514827
- requieres changed since pycrypto changed its provides

* Tue Oct 15 2013 pterjan <pterjan> 1.12.0-2.mga4
+ Revision: 499077
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 05 2013 philippem <philippem> 1.12.0-1.mga4
+ Revision: 491801
- Update to 1.12.0

* Wed Jul 10 2013 philippem <philippem> 1.10.1-1.mga4
+ Revision: 452609
- Update to 1.10.1

* Sun Jan 13 2013 umeabot <umeabot> 1.7.7.1-2.mga3
+ Revision: 379224
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 17 2011 ovitters <ovitters> 1.7.7.1-1.mga2
+ Revision: 144543
- new version 1.7.7.1

* Sun Jan 23 2011 ennael <ennael> 1.7.6-2.mga1
+ Revision: 35590
- imported package python-paramiko


* Tue Nov 02 2010 Crispin Boylan <crisb@mandriva.org> 1.7.6-2mdv2011.0
+ Revision: 591781
- Rebuild

* Sun Jan 10 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.7.6-1mdv2010.1
+ Revision: 489188
- update to new version 1.7.6

* Thu Sep 17 2009 Michael Scherer <misc@mandriva.org> 1.7.5-1mdv2010.0
+ Revision: 443919
- update to new version 1.7.5

* Tue Sep 15 2009 Thierry Vignaud <tv@mandriva.org> 1.7.4-3mdv2010.0
+ Revision: 442326
- rebuild

* Mon Dec 29 2008 Crispin Boylan <crisb@mandriva.org> 1.7.4-2mdv2009.1
+ Revision: 321177
- Rebuild for 2.6

* Fri Aug 15 2008 Michael Scherer <misc@mandriva.org> 1.7.4-1mdv2009.0
+ Revision: 272310
- new version
- new url

* Mon Mar 10 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.7.2-1mdv2008.1
+ Revision: 183316
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Dec 17 2007 Jérôme Soyer <saispo@mandriva.org> 1.6.4-1mdv2008.1
+ Revision: 122368
- New release 1.6.4 and bypass check


* Sun Jan 07 2007 Michael Scherer <misc@mandriva.org> 1.5.2-4mdv2007.0
+ Revision: 105220
- rebuild for python 2.5
- use %%rel scheme for mkrel
- Import python-paramiko

